==> nikola-7.6.0.tar.gz: nikola-7.6.0/nikola/data/themes/base/messages/messages_it.py <==
# -*- encoding:utf-8 -*-
from __future__ import unicode_literals

MESSAGES = {
    "%d min remaining to read": "ulteriori %d minuti di lettura",
    "(active)": "(attivo)",
    "Also available in:": "Disponibile anche in:",
    "Archive": "Archivio",
    "Categories": "Categorie",
    "Comments": "Commenti",
    "LANGUAGE": "Inglese",
    "Languages:": "Lingue:",
    "More posts about %s": "Altri articoli collegati %s",
    "Newer posts": "Articoli più recenti",
    "Next post": "Articolo successivo",
    "No posts found.": "Nessun articolo trovato.",
    "Nothing found.": "Non trovato.",
    "Older posts": "Articoli precedenti",
    "Original site": "Sito originale",
    "Posted:": "Pubblicato:",
    "Posts about %s": "Articoli su %s",
    "Posts for year %s": "Articoli per l'anno %s",
    "Posts for {month} {day}, {year}": "Articoli per il {day} {month} {year}",
    "Posts for {month} {year}": "Articoli per {month} {year}",
    "Previous post": "Articolo precedente",
    "Publication date": "Data di pubblicazione",
    "RSS feed": "Feed RSS",
    "Read in English": "Leggi in inglese",
    "Read more": "Continua la lettura",
    "Skip to main content": "Vai al testo principale",
    "Source": "Sorgente",
    "Subcategories:": "Sottocategorie:",
    "Tags and Categories": "Tag e Categorie",
    "Tags": "Tag",
    "Write your page here.": "Scrivi qui la tua pagina.",
    "Write your post here.": "Scrivi qui il tuo post.",
    "old posts, page %d": "vecchi articoli, pagina %d",
    "page %d": "pagina %d",
}

==> nikola-7.7.0.tar.gz: nikola-7.7.0/nikola/data/themes/base/messages/messages_it.py <==
# -*- encoding:utf-8 -*-
from __future__ import unicode_literals

MESSAGES = {
    "%d min remaining to read": "ulteriori %d minuti di lettura",
    "(active)": "(attivo)",
    "Also available in:": "Disponibile anche in:",
    "Archive": "Archivio",
    "Authors": "",
    "Categories": "Categorie",
    "Comments": "Commenti",
    "LANGUAGE": "Italiano",
    "Languages:": "Lingue:",
    "More posts about %s": "Altri articoli collegati %s",
    "Newer posts": "Articoli più recenti",
    "Next post": "Articolo successivo",
    "No posts found.": "Nessun articolo trovato.",
    "Nothing found.": "Non trovato.",
    "Older posts": "Articoli precedenti",
    "Original site": "Sito originale",
    "Posted:": "Pubblicato:",
    "Posts about %s": "Articoli su %s",
    "Posts by %s": "",
    "Posts for year %s": "Articoli per l'anno %s",
    "Posts for {month} {day}, {year}": "Articoli per il {day} {month} {year}",
    "Posts for {month} {year}": "Articoli per {month} {year}",
    "Previous post": "Articolo precedente",
    "Publication date": "Data di pubblicazione",
    "RSS feed": "Feed RSS",
    "Read in English": "Leggi in inglese",
    "Read more": "Continua la lettura",
    "Skip to main content": "Vai al testo principale",
    "Source": "Sorgente",
    "Subcategories:": "Sottocategorie:",
    "Tags and Categories": "Tag e categorie",
    "Tags": "Tag",
    "Uncategorized": "",
    "Updates": "",
    "Write your page here.": "Scrivi qui la tua pagina.",
    "Write your post here.": "Scrivi qui il tuo post.",
    "old posts, page %d": "vecchi articoli, pagina %d",
    "page %d": "pagina %d",
}
